==> algoliasearch-scala_2.11-1.8.0-sources.jar: algolia/definitions/BatchOperationUtils.scala <==
/*
 * Copyright (c) 2016 Algolia
 * http://www.algolia.com/
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package algolia.definitions

import org.json4s._

trait BatchOperationUtils {

  implicit val formats: Formats

  protected def hasObjectId(obj: AnyRef): (Boolean, JValue) = {
    val json = Extraction.decompose(obj)
    json \ "objectID" match {
      case JNothing => (false, json)
      case _ => (true, json)
    }
  }

  protected def addObjectId(obj: AnyRef, objectId: String): JValue = {
    val json: JValue = Extraction.decompose(obj)

    json \ "objectID" match {
      case JNothing => JObject(JField("objectID", JString(objectId))) merge json
      case _ => json
    }
  }

}

==> algoliasearch-scala_2.11-1.16.0-sources.jar: algolia/definitions/BatchOperationUtils.scala <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2016 Algolia
 * http://www.algolia.com/
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package algolia.definitions

import org.json4s._

trait BatchOperationUtils {

  implicit val formats: Formats

  protected def hasObjectId(obj: AnyRef): (Boolean, JValue) = {
    val json = Extraction.decompose(obj)
    json \ "objectID" match {
      case JNothing => (false, json)
      case _ => (true, json)
    }
  }

  protected def addObjectId(obj: AnyRef, objectId: String): JValue = {
    val json: JValue = Extraction.decompose(obj)

    json \ "objectID" match {
      case JNothing =>
        JObject(JField("objectID", JString(objectId))) merge json
      case _ => json
    }
  }

}
